---
name: Docs
about: Issue related to Salt Documentation
title: "[DOCS]"
labels: documentation, needs-triage
assignees: ''

---

**Description**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Suggested Fix**
What did you expect to see in the documentation that is missing or needs updating?

**Type of documentation**
This could be module documentation or a guide.

**Location or format of documentation**
Insert page URL if applicable.

**Additional context**
Add any other context or screenshots here.
